@@ -44,6 +44,18 @@ def _parse_note_dom(note: EvernoteNote) -> Optional[Tag]:
         logger.error(f"Failed to extract DOM from note '{note.title}'")
         return None
 
+    return _filter_yinxiang_markdown(note_dom)
+
+
+def _filter_yinxiang_markdown(note_dom: Tag) -> Tag:
+    last_block = note_dom.contents[-1]
+
+    if not isinstance(last_block, Tag):
+        return note_dom
+
+    if "display:none" in last_block.attrs.get("style", ""):
+        last_block.extract()
+
     return note_dom
 
 
